<?php

namespace ProjectManagers\ProjectManager\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use ProjectManagers\ProjectManager\Models\Manager;

class ManagerPolicy
{

    /**
     * Determine if the given user can view the manager.
     *
     * @param UserPolicyInterface $authUser
     * @param Manager $manager
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Manager $manager)
    {
        if ($authUser->canDo('project_manager.manager.view') && $authUser->isAdmin()) {
            return true;
        }

        return $manager->user_id == user_id() && $manager->user_type == user_type();
    }

    /**
     * Determine if the given user can create a manager.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('project_manager.manager.create');
    }

    /**
     * Determine if the given user can update the given manager.
     *
     * @param UserPolicyInterface $authUser
     * @param Manager $manager
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Manager $manager)
    {
        if ($authUser->canDo('project_manager.manager.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $manager->user_id == user_id() && $manager->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given manager.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Manager $manager)
    {
        return $manager->user_id == user_id() && $manager->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given manager.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Manager $manager)
    {
        if ($authUser->canDo('project_manager.manager.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given manager.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Manager $manager)
    {
        if ($authUser->canDo('project_manager.manager.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
